<?php

namespace Ems\portalGestor\Controller;

use Ems\portalGestor\Service\HierarquiaService;
use Ems\portalGestor\Util\ExpectedException;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class HierarquiaController {
    /** @var HierarquiaService */
    protected $hierarquiaService;

    public function __construct(
        HierarquiaService $hierarquiaService
    ) {
        $this->hierarquiaService = $hierarquiaService;
    }

    public function getTiposHierarquia(
        DTO\Request\Filter  $request,
        DTO\Response        $response
    ) {
        try {
            $row = $request->getParameters();
            $nrOrg = (int) $row['NRORG'];

            $tiposHierarquia = $this->hierarquiaService->getTiposHierarquia($nrOrg);

            $response->addDataSet(new DataSet('data', $tiposHierarquia));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getHierarquiaOrganizacao(
        DTO\Request\Filter  $request,
        DTO\Response        $response
    ) {
        try {
            $row = $request->getParameters();
            $nrOrg = (int) $row['NRORG'];
            $nrVinculo = (int) $row['NRVINCULOM'];

            $hierarquia = $this->hierarquiaService->getHierarquiaOrganizacao($nrOrg, $nrVinculo);

            $response->addDataSet(new DataSet('data', $hierarquia));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

}
